==> yy-formulas-1.0.1.tgz: package/es/components/DocumentComponents.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (typeof call === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React from 'react';
import PropTypes from 'prop-types';
import { polyfill } from 'react-lifecycles-compat';
import Tree, { TreeNode } from 'rc-tree';

var DocumentComponents =
/*#__PURE__*/
function (_React$Component) {
  _inherits(DocumentComponents, _React$Component);

  function DocumentComponents(props) {
    var _this;

    _classCallCheck(this, DocumentComponents);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(DocumentComponents).call(this, props));
    _this.onSelect = _this.onSelect.bind(_assertThisInitialized(_this));
    _this.onChange = _this.onChange.bind(_assertThisInitialized(_this));
    _this.onButClick = _this.onButClick.bind(_assertThisInitialized(_this));
    _this.loop = _this.loop.bind(_assertThisInitialized(_this));
    _this.state = {
      selectedKeys: [],
      value: ''
    };
    return _this;
  }

  _createClass(DocumentComponents, [{
    key: "onSelect",
    value: function onSelect(selectkey) {
      // console.log([selectkey,...arr])
      var selectedKeys = [];

      if (selectkey.length > 0) {
        selectedKeys = selectkey;
        var code = selectkey[0];
        var key = code.substr(code.indexOf('.') + 1);
        this.props.onInsertValue(' ' + key + ' ');
      } else if (this.state.selectedKeys.length > 0) {
        var _code = this.state.selectedKeys[0];

        var _key = _code.substr(_code.indexOf('.') + 1);

        this.props.onInsertValue(' ' + _key + ' ');
      }

      this.setState({
        selectedKeys: selectedKeys
      });
    }
  }, {
    key: "onChange",
    value: function onChange(event) {
      var value = event.target.value;
      this.setState({
        value: value
      });
    }
  }, {
    key: "onButClick",
    value: function onButClick() {
      var value = this.state.value;
      var selectedKeys = this.state.selectedKeys;
      var selectedKeysList = [];
      var DocumentTreeData = this.props.DocumentTreeData;

      var loop = function loop(data) {
        data.map(function (item) {
          var reg = new RegExp(value, 'igm');

          if (reg.test(item.title)) {
            selectedKeysList.push(item.key);
          }

          if (item.children && item.children.length > 0) {
            loop(item.children);
          }
        });
      };

      if (value) {
        loop(DocumentTreeData);

        if (selectedKeysList.length > 0) {
          if (selectedKeys.length === 0) {
            selectedKeys.push(selectedKeysList[0]);
          } else {
            if (selectedKeysList.includes(selectedKeys[0])) {
              var index = selectedKeysList.indexOf(selectedKeys[0]);

              if (selectedKeysList.length > index) {
                selectedKeys = [selectedKeysList[index + 1]];
              } else {
                selectedKeys = [selectedKeysList[0]];
              }
            } else {
              selectedKeys = [selectedKeysList[0]];
            }
          }
        }

        this.setState({
          selectedKeys: selectedKeys
        });
      }

      console.log([selectedKeysList, value, selectedKeys]);
    }
  }, {
    key: "loop",
    value: function loop(data) {
      var _this2 = this;

      return data.map(function (item) {
        // let isflag = false
        // if(value && value.length > 0){
        //   let reg = new RegExp(value,'igm')
        //   if(reg.test(item.title)){
        //     selectedKeys.push(item.key)
        //   }
        //   // console.log(isflag)
        // }else{
        //   // console.log(isflag)
        // }
        if (item.children && item.children.length > 0) {
          return React.createElement(TreeNode, {
            title: item.title,
            isLeaf: false,
            key: item.key,
            code: item.code,
            disabled: item.disabled //className={isflag ? 'yy-search-selected' : ''}

          }, _this2.loop(item.children));
        } else {
          return React.createElement(TreeNode, {
            title: item.title,
            isLeaf: true,
            key: item.key,
            code: item.code,
            disabled: item.disabled //className={isflag ? 'yy-search-selected' : ''}

          });
        }
      });
    }
  }, {
    key: "render",
    value: function render() {
      var DocumentTreeData = this.props.DocumentTreeData; // let value = this.state.value
      // let selectedKeys = []
      // const loop = (data)=>{
      //   // console.log(data)
      // }

      return React.createElement("div", {
        className: "yy-tab-content"
      }, React.createElement("form", {
        className: "form-inline"
      }, React.createElement("span", null, "\u5B9A\u4F4D\uFF1A"), React.createElement("div", {
        className: "form-group"
      }, React.createElement("input", {
        className: "form-control",
        onChange: this.onChange,
        value: this.state.value
      }), React.createElement("button", {
        style: {
          marginLeft: '10px'
        },
        className: "btn btn-default",
        onClick: this.onButClick,
        type: "button"
      }, "\u786E\u5B9A"))), React.createElement(Tree, {
        prefixCls: "rc-tree",
        showLine: true,
        showIcon: false,
        checkable: false,
        defaultExpandAll: true,
        className: "myCls",
        autoExpandParent: true,
        selectedKeys: this.state.selectedKeys,
        onSelect: this.onSelect
      }, this.loop(DocumentTreeData))) // <div>{JSON.stringify(this.props.item)}单据字段单据字段单据字段单据字段单据字段</div>
      ;
    }
  }]);

  return DocumentComponents;
}(React.Component);

DocumentComponents.propTypes = {
  item: PropTypes.object,
  DocumentTreeData: PropTypes.array
};
DocumentComponents.defaultProps = {
  item: {},
  DocumentTreeData: []
};
polyfill(DocumentComponents);
export default DocumentComponents;

==> yy-formulas-1.0.7.tgz: package/es/components/DocumentComponents.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (typeof call === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

import React from 'react';
import PropTypes from 'prop-types';
import { polyfill } from 'react-lifecycles-compat';
import Tree, { TreeNode } from 'rc-tree';

var DocumentComponents =
/*#__PURE__*/
function (_React$Component) {
  _inherits(DocumentComponents, _React$Component);

  function DocumentComponents(props) {
    var _this;

    _classCallCheck(this, DocumentComponents);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(DocumentComponents).call(this, props));
    _this.onSelect = _this.onSelect.bind(_assertThisInitialized(_this));
    _this.onChange = _this.onChange.bind(_assertThisInitialized(_this));
    _this.onButClick = _this.onButClick.bind(_assertThisInitialized(_this));
    _this.loop = _this.loop.bind(_assertThisInitialized(_this));
    _this.state = {
      selectedKeys: [],
      value: ''
    };
    return _this;
  }

  _createClass(DocumentComponents, [{
    key: "onSelect",
    value: function onSelect(selectkey) {
      // console.log([selectkey,...arr])
      var selectedKeys = [];

      if (selectkey.length > 0) {
        selectedKeys = selectkey;
        var code = selectkey[0];
        var key = code.substr(code.indexOf('.') + 1);
        this.props.onInsertValue(' ' + key + ' ');
      } else if (this.state.selectedKeys.length > 0) {
        var _code = this.state.selectedKeys[0];

        var _key = _code.substr(_code.indexOf('.') + 1);

        this.props.onInsertValue(' ' + _key + ' ');
      }

      this.setState({
        selectedKeys: selectedKeys
      });
    }
  }, {
    key: "onChange",
    value: function onChange(event) {
      var value = event.target.value;
      this.setState({
        value: value
      });
    }
  }, {
    key: "onButClick",
    value: function onButClick() {
      var value = this.state.value;
      var selectedKeys = this.state.selectedKeys;
      var selectedKeysList = [];
      var DocumentTreeData = this.props.DocumentTreeData;

      var loop = function loop(data) {
        data.map(function (item) {
          var reg = new RegExp(value, 'igm');

          if (reg.test(item.title)) {
            selectedKeysList.push(item.key);
          }

          if (item.children && item.children.length > 0) {
            loop(item.children);
          }
        });
      };

      if (value) {
        loop(DocumentTreeData);

        if (selectedKeysList.length > 0) {
          if (selectedKeys.length === 0) {
            selectedKeys.push(selectedKeysList[0]);
          } else {
            if (selectedKeysList.includes(selectedKeys[0])) {
              var index = selectedKeysList.indexOf(selectedKeys[0]);

              if (selectedKeysList.length > index) {
                selectedKeys = [selectedKeysList[index + 1]];
              } else {
                selectedKeys = [selectedKeysList[0]];
              }
            } else {
              selectedKeys = [selectedKeysList[0]];
            }
          }
        }

        this.setState({
          selectedKeys: selectedKeys
        });
      } // console.log([selectedKeysList,value,selectedKeys])

    }
  }, {
    key: "loop",
    value: function loop(data) {
      var _this2 = this;

      return data.map(function (item) {
        // let isflag = false
        // if(value && value.length > 0){
        //   let reg = new RegExp(value,'igm')
        //   if(reg.test(item.title)){
        //     selectedKeys.push(item.key)
        //   }
        //   // console.log(isflag)
        // }else{
        //   // console.log(isflag)
        // }
        if (item.children && item.children.length > 0) {
          return React.createElement(TreeNode, {
            title: item.title,
            isLeaf: false,
            key: item.key,
            code: item.code,
            disabled: item.disabled //className={isflag ? 'yy-search-selected' : ''}

          }, _this2.loop(item.children));
        } else {
          return React.createElement(TreeNode, {
            title: item.title,
            isLeaf: true,
            key: item.key,
            code: item.code,
            disabled: item.disabled //className={isflag ? 'yy-search-selected' : ''}

          });
        }
      });
    }
  }, {
    key: "render",
    value: function render() {
      var DocumentTreeData = this.props.DocumentTreeData; // let value = this.state.value
      // let selectedKeys = []
      // const loop = (data)=>{
      //   // console.log(data)
      // }

      return React.createElement("div", {
        className: "yy-tab-content"
      }, React.createElement("form", {
        className: "form-inline"
      }, React.createElement("span", null, this.props.item.positionName), React.createElement("div", {
        className: "form-group"
      }, React.createElement("input", {
        className: "form-control",
        onChange: this.onChange,
        value: this.state.value
      })), React.createElement("button", {
        style: {
          marginLeft: '10px'
        },
        className: "btn btn-default",
        onClick: this.onButClick,
        type: "button"
      }, this.props.item.okName)), React.createElement(Tree, {
        prefixCls: "rc-tree",
        showLine: true,
        showIcon: false,
        checkable: false,
        defaultExpandAll: true,
        className: "myCls",
        autoExpandParent: true,
        selectedKeys: this.state.selectedKeys,
        onSelect: this.onSelect
      }, this.loop(DocumentTreeData)));
    }
  }]);

  return DocumentComponents;
}(React.Component);

DocumentComponents.propTypes = {
  item: PropTypes.object,
  DocumentTreeData: PropTypes.array
};
DocumentComponents.defaultProps = {
  item: {},
  DocumentTreeData: []
};
polyfill(DocumentComponents);
export default DocumentComponents;
